@@ -10,7 +10,7 @@ def extract(record, dimension):
 
 
 def transform(records, number_of_rotated_keys):
-    # log(f'MegaStorm - Transform -> {records.get("key")} {len(records.get("value"))}')
+    tracker_log(f'Transform.input {records}', f'RotateUD-1to5-W - ')
 
     df = pd.DataFrame(records.get("value"))
     df_sort = df.sort_values('ts')
@@ -42,6 +42,14 @@ def transform(records, number_of_rotated_keys):
             })
         else:
             [results.get('reinject').append({
+                'key': create_key_name(
+                    Type.HLL.value,
+                    '',
+                    row[0],
+                    row[2],
+                    row[1],
+                    Metric.UNIQUE_DEVICES.value
+                ),
                 'dimension': row[0],
                 'ts': row[1],
                 'id': row[2]
@@ -50,6 +58,7 @@ def transform(records, number_of_rotated_keys):
         i += expected_rows
         j += expected_rows
 
+    tracker_log(f'Transform.output {results}', f'RotateUD-1to5-W - ')
     return results
 
 
@@ -61,14 +70,22 @@ def load(job_name, records, dimension, write_to_ts, timeseries_name, key_expire_
         else:
             return ts
 
+    capped_stream = get_maxlen_capped_stream(timeseries_name, dimension)
+
+    # tracker_log(f'UD - MAXLEN {type(capped_stream)} {capped_stream}')
+
     for hll_reinject in records.get('reinject'):
-        execute('XADD', reinject_stream_name, '*', 'id', hll_reinject.get('id'), 'dimension',
-                hll_reinject.get('dimension'), 'ts', hll_reinject.get('ts'))
+        execute('XADD', reinject_stream_name, 'MAXLEN', f'{capped_stream}', '*',
+                'id', hll_reinject.get('id'),
+                'dimension', hll_reinject.get('dimension'),
+                'ts', hll_reinject.get('ts'),
+                'merged_key', hll_reinject.get('key'))
 
     for hll_merge in records.get("merge"):
         if execute('EXISTS', hll_merge.get('name')) != 1:
             execute('PFMERGE', hll_merge.get('name'), *hll_merge.get('keys'))
-            tracker_log(f'Merge Unique Devices {hll_merge.get("name")}', f'{job_name} ')
+
+            tracker_log(f'Merge Unique Devices {hll_merge}', f'{job_name} - ')
 
             parsed_key_name = parse_key_name(hll_merge.get('name'))
 
@@ -89,35 +106,41 @@ def load(job_name, records, dimension, write_to_ts, timeseries_name, key_expire_
                     metric=Metric.UNIQUE_DEVICES.value)
 
                 if dimension == Dimension.WEBSITE.value:
-                    record_infos = \
-                    execute('FT.SEARCH', index_name, f'@id:{{{hll_merge.get("id")}}}', 'RETURN', '1', 'name')
+                    record_infos = execute('FT.SEARCH', index_name, f'@id:{{{hll_merge.get("id")}}}', 'RETURN', '3',
+                                           'name', 'AS', 'website_name')
                     # tracker_log(f'Get {dimension} infos - {record_infos}', f'{job_name} ')
                     execute('TS.ADD', timeseries_key_name, get_ts(parsed_key_name.get('ts')), unique_devices,
                             'ON_DUPLICATE', 'LAST',
-                            'LABELS', 'dimension', dimension, Dimension.METRIC.value, Metric.UNIQUE_DEVICES.value,
+                            'LABELS', 'ts_name', timeseries_name,
+                            'dimension', dimension, Dimension.METRIC.value, Metric.UNIQUE_DEVICES.value,
                             'website_id', hll_merge.get('id'), *record_infos[-1])
-                    tracker_log(f'Write to Timeseries {hll_merge.get("id")}->{timeseries_key_name}', f'{job_name} ')
+                    # tracker_log(f'Write to Timeseries {hll_merge.get("id")}->{timeseries_key_name}', f'{job_name} ')
+                    tracker_log(f'Write {unique_devices} devices to {timeseries_key_name} at {get_ts(parsed_key_name.get("ts"))}', f'{job_name} - ')
                 elif dimension == Dimension.SECTION.value:
-                    record_infos = execute('FT.SEARCH', index_name, f'@id:{{{hll_merge.get("id")}}}', 'RETURN', '3',
-                                           'pretty_name', 'website_id', 'website_name')
+                    record_infos = execute('FT.SEARCH', index_name, f'@id:{{{hll_merge.get("id")}}}', 'RETURN', '5',
+                                           'name', 'AS', 'section_name', 'website_id', 'website_name')
                     # tracker_log(f'Get {dimension} infos - {record_infos}', f'{job_name} ')
                     execute('TS.ADD', timeseries_key_name, get_ts(parsed_key_name.get("ts")), unique_devices,
                             'ON_DUPLICATE', 'LAST',
-                            'LABELS', 'dimension', dimension, Dimension.METRIC.value, Metric.UNIQUE_DEVICES.value,
+                            'LABELS', 'ts_name', timeseries_name,
+                            'dimension', dimension, Dimension.METRIC.value, Metric.UNIQUE_DEVICES.value,
                             'section_id', hll_merge.get('id'), *record_infos[-1])
-                    tracker_log(f'Write to Timeseries {hll_merge.get("id")}->{timeseries_key_name}', f'{job_name} ')
+                    # tracker_log(f'Write to Timeseries {hll_merge.get("id")}->{timeseries_key_name}', f'{job_name} ')
                 elif dimension == Dimension.PAGE.value:
                     record_infos = execute('FT.SEARCH', index_name, f'@id:{{{hll_merge.get("id")}}}', 'RETURN', '5',
-                                           'website_id', 'website_name', 'section_id',
-                                           'section_pretty_name', 'article_id')
+                                           'website_id', 'website_name', 'section_id', 'section_name', 'article_id')
                     # tracker_log(f'Get {dimension} infos - {record_infos}', f'{job_name} ')
                     execute('TS.ADD', timeseries_key_name, get_ts(parsed_key_name.get("ts")), unique_devices,
                             'ON_DUPLICATE', 'LAST',
-                            'LABELS', 'dimension', dimension, Dimension.METRIC.value, Metric.UNIQUE_DEVICES.value,
+                            'LABELS', 'ts_name', timeseries_name,
+                            'dimension', dimension, Dimension.METRIC.value, Metric.UNIQUE_DEVICES.value,
                             'page_id', hll_merge.get('id'), *record_infos[-1])
-                    tracker_log(f'Write to Timeseries {hll_merge.get("id")}->{timeseries_key_name}', f'{job_name} ')
+                    # tracker_log(f'Write to Timeseries {hll_merge.get("id")}->{timeseries_key_name}', f'{job_name} ')
 
-            execute('XADD', output_stream_name, '*', 'dimension', dimension, 'id', hll_merge.get('id'), 'ts',
-                    parsed_key_name.get('ts'))
+            execute('XADD', output_stream_name, 'MAXLEN', f'{capped_stream}', '*',
+                    'dimension', dimension,
+                    'id', hll_merge.get('id'),
+                    'ts', parsed_key_name.get('ts'),
+                    'merged_key', hll_merge.get('name'))
 
-            # execute('EXPIRE', hll_merge.get('name'), key_expire_duration_sc)
+            execute('EXPIRE', hll_merge.get('name'), key_expire_duration_sc)
