@@ -29,7 +29,7 @@ class Website:
         else:
             dt = datetime.fromtimestamp(int(self.last_visited) / 1000) if self.last_visited is not None else None
             rounded_last_visited = int(round_time(dt).timestamp() * 1000)
-            tracker_log(f'Rounded time: {dt} to {rounded_last_visited}', f'Website - ')
+            # tracker_log(f'Rounded time: {dt} to {rounded_last_visited}', f'Website - ')
             self.dimension_key = f'{Type.JSON.value}::{Dimension.WEBSITE.value}:{self.id}::'
             self.dimension_ts_key = f'::{Dimension.WEBSITE.value}:{self.id}:{rounded_last_visited}:'
             self.metric_pageviews_key = f'{Type.CMS.value}::{Dimension.WEBSITE.value}::{rounded_last_visited}:{Metric.PAGEVIEWS.value}'
@@ -56,6 +56,8 @@ class Website:
             # log(f'S-create_metrics: key {self.metric_pageviews_key} already exists')
             pass
 
+        execute('PFADD', self.metric_unique_device_key)
+
     def incr_metrics(self, page_id, device_id):
         # Fixme: increment by page_id
         execute('CMS.INCRBY', self.metric_pageviews_key, self.id, 1)
@@ -76,10 +78,11 @@ class Website:
     def has_metrics(self):
         # Todo: check if all metrics exists?
         x = execute('EXISTS', self.metric_pageviews_key)
-        log(f'EXISTS {self.metric_pageviews_key} => {x}')
-        z = execute('EXISTS', self.metric_unique_device_key)
-        log(f'EXISTS {self.metric_unique_device_key} => {z}')
-        return x + z
+        # log(f'EXISTS {self.metric_pageviews_key} => {x}')
+        # z = execute('EXISTS', self.metric_unique_device_key)
+        # log(f'EXISTS {self.metric_unique_device_key} => {z}')
+        # return x + z
+        return x
 
     def update_last_visited(self):
         execute('JSON.SET', self.dimension_key, '.last_visited', self.last_visited)
@@ -106,7 +109,7 @@ class Website:
 
 
     def log_new_minute(self):
-        tracker_log(f'{parse_key_name(self.dimension_ts_key).get("ts")} - Create new bucket, Incr metrics, update last visited, send message to other services', f'Website - ')
+        tracker_log(f'NEW MINUTE - {parse_key_name(self.dimension_ts_key).get("ts")}', f'Website - ')
 
 
 def load_website(website, section, page, device, output_stream_names):
@@ -119,8 +122,7 @@ def load_website(website, section, page, device, output_stream_names):
         website.write_metadata(stream_names=output_stream_names)
         website.send_to_enrich()
     else:
-        if website.has_metrics() < 2:
-            # New Minute? Write to TS? Is it always the same interval?
+        if website.has_metrics() < 1:
             website.log_new_minute()
             website.create_metrics()
             website.incr_metrics(page.id, device.id)
